@@ -15,7 +15,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.42'
+__version__ = '0.1.43'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -39,7 +39,8 @@ __info__ = {
     '2022/08/01: 0.1.39 加入註解，把一些東西拆開來，以免每次mypylib都要載入一堆 module',
     '2022/08/05: 0.1.40 繼續拆開一些東西 tredis',
     '2022/08/12: 0.1.41 Remove password and 加入 finmind',
-    '2022/08/12: 0.1.42 fix redis 跳出問題'
+    '2022/08/12: 0.1.42 fix redis 跳出問題',
+    '2022/08/18: 0.1.43 修改 redis_msg_sender(), 增加 channel參數',
 }
 
 
