@@ -151,7 +151,7 @@ class Market(dict):
 
 
 class SJ_wrapper:
-    def __init__(self, _id='H121933940', password='123edcxzaqws'):
+    def __init__(self, _id='H121933940', password='123'):
         self._id = _id
         self.password = password
 
@@ -161,7 +161,7 @@ class SJ_wrapper:
 
 
 class SJ_downloader(SJ_wrapper):
-    def __init__(self, _id='H121933940', password='123edcxzaqws'):
+    def __init__(self, _id='H121933940', password='123'):
         super(SJ_downloader, self).__init__(_id=_id, password=password)
 
         self.ticks = None
@@ -180,9 +180,7 @@ class SJ_downloader(SJ_wrapper):
 
 
 def unit_test_SJ_downloader():
-    # downloader = SJ_downloader(_id='F130153547', password='qwer0000')
-    downloader = SJ_downloader(_id='H121933940', password='123edcxzaqws')
-    # downloader = SJ_downloader(_id='F130153547', password='qwer0000')
+    downloader = SJ_downloader(_id='H121933940', password='123')
 
     if not os.path.isfile('trade_days.txt'):
         trade_days = get_trade_days('2018-01-01', datetime.datetime.today())
